# SPDX-License-Identifier: Apache-2.0


# First Party
from granite_common.base.io import (
    Retriever,
)
from granite_common.retrievers import util
from granite_common.retrievers.elasticsearch import (
    ElasticsearchRetriever,
)
from granite_common.retrievers.embeddings import (
    InMemoryRetriever,
    compute_embeddings,
    write_embeddings,
)

# Expose public symbols at `granite_common.io.retrievers` to save users from typing
__all__ = [
    "Retriever",
    "InMemoryRetriever",
    "ElasticsearchRetriever",
    "compute_embeddings",
    "write_embeddings",
    "util",
]
